@@ -355,7 +355,8 @@ class FriendSelectionPopup(
         val friendList = FriendPickerList(playerPicker, ::friendSelected)
         pickerPane.topTable.add(friendList)
         pickerPane.rightSideButton.setText("Select friend".tr())
-        pickerPane.closeButton.onClick(::close)
+        pickerPane.closeButton.onActivation(::close)
+        pickerPane.closeButton.keyShortcuts.add(KeyCharAndCode.BACK)
         pickerCell.setActor<PickerPane>(pickerPane)
         pickerPane.rightSideButton.onClick {
             close()
@@ -366,6 +367,8 @@ class FriendSelectionPopup(
                 playerPicker.update()
             }
         }
+
+        clickBehindToClose = true
     }
 
     private fun friendSelected(friendName: String) {
@@ -460,6 +463,7 @@ private class NationPickerPopup(
         closeButton.keyShortcuts.add(KeyCharAndCode.BACK)
         closeButton.setPosition(buttonsOffsetFromEdge, buttonsOffsetFromEdge, Align.bottomLeft)
         innerTable.addActor(closeButton)
+        clickBehindToClose = true
 
         val okButton = "OtherIcons/Checkmark".toImageButton(Color.LIME)
         okButton.onClick { returnSelected() }
