@@ -5,13 +5,13 @@ import com.badlogic.gdx.scenes.scene2d.Actor
 import com.badlogic.gdx.scenes.scene2d.Group
 import com.badlogic.gdx.scenes.scene2d.Touchable
 import com.badlogic.gdx.scenes.scene2d.ui.Cell
-import com.badlogic.gdx.scenes.scene2d.ui.Container
 import com.badlogic.gdx.scenes.scene2d.ui.Label
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.utils.Align
 import com.unciv.logic.civilization.Civilization
 import com.unciv.models.ruleset.tile.ResourceType
 import com.unciv.models.ruleset.tile.TileResource
+import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.stats.Stats
 import com.unciv.models.translations.tr
 import com.unciv.ui.components.Fonts
@@ -24,6 +24,7 @@ import com.unciv.ui.components.extensions.onClick
 import com.unciv.ui.components.extensions.setFontColor
 import com.unciv.ui.components.extensions.setFontSize
 import com.unciv.ui.components.extensions.toLabel
+import com.unciv.ui.components.extensions.toStringSigned
 import com.unciv.ui.components.extensions.toTextButton
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.popups.popups
@@ -53,7 +54,7 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
     private val happinessLabel = "0".toLabel()
     private val cultureLabel = "0".toLabel(colorFromRGB(210, 94, 210))
     private val faithLabel = "0".toLabel(colorFromRGB(168, 196, 241))
-    private data class ResourceActors(val resource: TileResource, val Label: Label, val icon: Group)
+    private data class ResourceActors(val resource: TileResource, val label: Label, val icon: Group)
     private val resourceActors = ArrayList<ResourceActors>(12)
     private val happinessImage = Group()
 
@@ -201,7 +202,6 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
     private class SelectedCivilizationTable(worldScreen: WorldScreen) : Table(BaseScreen.skin) {
         private var selectedCiv = ""
         private val selectedCivLabel = "".toLabel()
-        private val selectedCivIconHolder = Container<Actor>()
         private val menuButton = ImageGetter.getImage("OtherIcons/MenuIcon")
 
         init {
@@ -225,13 +225,8 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
                 worldScreen.game.pushScreen(civilopediaScreen)
             }
 
-            selectedCivIconHolder.onClick {
-                worldScreen.openEmpireOverview()
-            }
-
             add(menuButton).size(50f).padRight(0f)
-            add(selectedCivLabel).padRight(0f)
-            add(selectedCivIconHolder).size(35f)
+            add(selectedCivLabel).padRight(10f)
             pack()
         }
 
@@ -241,9 +236,6 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
             this.selectedCiv = newCiv
 
             selectedCivLabel.setText(newCiv.tr())
-            val nation = worldScreen.gameInfo.ruleset.nations[worldScreen.selectedCiv.civName]!!
-            val selectedCivIcon = ImageGetter.getNationPortrait(nation, 35f)
-            selectedCivIconHolder.actor = selectedCivIcon
             invalidate()
             pack()
         }
@@ -347,14 +339,26 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
         turnsLabel.setText(Fonts.turn + "" + civInfo.gameInfo.turns + " | " + yearText)
         resourcesWrapper.clearChildren()
         var firstPadLeft = 20f  // We want a distance from the turns entry to the first resource, but only if any resource is displayed
-        val civResources = civInfo.getCivResources()
+        val civResources = civInfo.getCivResourcesByName()
+        val civResourceSupply = civInfo.getCivResourceSupply()
         for ((resource, label, icon) in resourceActors) {
-            if (resource.revealedBy != null && !civInfo.tech.isResearched(resource.revealedBy!!))
+            if (resource.hasUnique(UniqueType.NotShownOnWorldScreen)) continue
+
+            val amount = civResources[resource.name] ?: 0
+
+            if (resource.revealedBy != null && !civInfo.tech.isResearched(resource.revealedBy!!)
+                    && amount == 0) // You can trade for resources you cannot process yourself yet
                 continue
+
             resourcesWrapper.add(icon).padLeft(firstPadLeft).padRight(0f)
             firstPadLeft = 5f
-            val amount = civResources.get(resource, "All")?.amount ?: 0
-            label.setText(amount)
+            if (!resource.isStockpiled())
+                label.setText(amount)
+            else {
+                val perTurn = civResourceSupply.firstOrNull { it.resource == resource }?.amount ?: 0
+                if (perTurn == 0) label.setText(amount)
+                else label.setText("$amount (${perTurn.toStringSigned()})")
+            }
             resourcesWrapper.add(label).padTop(8f)  // digits don't have descenders, so push them down a little
         }
 
